==> rendition-9.4.0.tgz: package/dist_esm5/components/Terminal/index.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import cloneDeep from 'lodash/cloneDeep';
import * as React from 'react';
import styled from 'styled-components';
import { Terminal as Xterm } from 'xterm';
import { fit as fitTerm } from 'xterm/lib/addons/fit/fit';
import theme from '../../theme';
import { Box } from '../Grid';
import defaultXtermStyle from './XTermDefaultStyle';
var TtyContainer = styled(Box)(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tposition: relative;\n\theight: 100%;\n\n\t", "\n\n\t.xterm-viewport::-webkit-scrollbar-track {\n\t\tbackground-color: transparent;\n\t\tborder-bottom-right-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar {\n\t\twidth: 10px;\n\t\tbackground-color: transparent;\n\t\tborder-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar-thumb {\n\t\tbackground-color: #e9e9e9;\n\t}\n"], ["\n\tposition: relative;\n\theight: 100%;\n\n\t", "\n\n\t.xterm-viewport::-webkit-scrollbar-track {\n\t\tbackground-color: transparent;\n\t\tborder-bottom-right-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar {\n\t\twidth: 10px;\n\t\tbackground-color: transparent;\n\t\tborder-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar-thumb {\n\t\tbackground-color: #e9e9e9;\n\t}\n"])), defaultXtermStyle);
var TtyInner = styled.div(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tright: 0;\n\tbottom: 0;\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tright: 0;\n\tbottom: 0;\n"])));
var Terminal = (function (_super) {
    tslib_1.__extends(Terminal, _super);
    function Terminal(props) {
        var _this = _super.call(this, props) || this;
        _this.termConfig = assign({}, props.config, {
            cols: 80,
            cursorBlink: false,
            rows: 24,
            fontFamily: props.theme ? props.theme.monospace : theme.monospace,
            lineHeight: 1.4,
            theme: {
                background: '#343434',
                cursor: props.nonInteractive ? '#343434' : undefined,
            },
        });
        if (_this.props.ttyInstance) {
            _this.tty = _this.props.ttyInstance;
        }
        else {
            _this.tty = new Xterm(cloneDeep(_this.termConfig));
        }
        _this.resize = _this.resize.bind(_this);
        return _this;
    }
    Terminal.prototype.componentDidMount = function () {
        var _this = this;
        this.open();
        if (this.props.ttyInstance) {
            this.tty.setOption('theme', this.termConfig.theme);
        }
        setTimeout(function () {
            if (_this.props.nonInteractive && document.execCommand) {
                _this.tty.attachCustomKeyEventHandler(function (e) {
                    if (e.ctrlKey && e.keyCode === 67) {
                        document.execCommand('copy');
                        return false;
                    }
                    return true;
                });
            }
            window.addEventListener('resize', _this.resize);
            _this.resize();
        }, 100);
    };
    Terminal.prototype.componentWillUnmount = function () {
        window.removeEventListener('resize', this.resize);
        if (!this.props.persistent) {
            this.tty.destroy();
        }
    };
    Terminal.prototype.destroy = function () {
        window.removeEventListener('resize', this.resize);
        this.tty.destroy();
    };
    Terminal.prototype.open = function () {
        this.tty.open(this.mountElement);
        this.tty.focus();
    };
    Terminal.prototype.resize = function () {
        fitTerm(this.tty);
    };
    Terminal.prototype.clear = function () {
        this.tty.clear();
    };
    Terminal.prototype.writeln = function (line) {
        this.tty.writeln(line);
    };
    Terminal.prototype.write = function (text) {
        this.tty.write(text);
    };
    Terminal.prototype.render = function () {
        var _this = this;
        return (React.createElement(TtyContainer, { color: this.props.color },
            React.createElement(TtyInner, { ref: function (el) { return (_this.mountElement = el); } })));
    };
    return Terminal;
}(React.Component));
export default Terminal;
var templateObject_1, templateObject_2;

==> rendition-11.13.0.tgz: package/dist_esm5/components/Terminal/index.js <==
import { __extends, __makeTemplateObject } from "tslib";
import assign from 'lodash/assign';
import cloneDeep from 'lodash/cloneDeep';
import * as React from 'react';
import styled from 'styled-components';
import { Terminal as Xterm } from 'xterm';
import { fit as fitTerm } from 'xterm/lib/addons/fit/fit';
import theme from '../../theme';
import { Box } from '../Grid';
import defaultXtermStyle from './XTermDefaultStyle';
var TtyContainer = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n\theight: 100%;\n\n\t", "\n\n\t.xterm-viewport::-webkit-scrollbar-track {\n\t\tbackground-color: transparent;\n\t\tborder-bottom-right-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar {\n\t\twidth: 10px;\n\t\tbackground-color: transparent;\n\t\tborder-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar-thumb {\n\t\tbackground-color: #e9e9e9;\n\t}\n"], ["\n\tposition: relative;\n\theight: 100%;\n\n\t", "\n\n\t.xterm-viewport::-webkit-scrollbar-track {\n\t\tbackground-color: transparent;\n\t\tborder-bottom-right-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar {\n\t\twidth: 10px;\n\t\tbackground-color: transparent;\n\t\tborder-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar-thumb {\n\t\tbackground-color: #e9e9e9;\n\t}\n"])), defaultXtermStyle);
var TtyInner = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tright: 0;\n\tbottom: 0;\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tright: 0;\n\tbottom: 0;\n"])));
var Terminal = (function (_super) {
    __extends(Terminal, _super);
    function Terminal(props) {
        var _this = _super.call(this, props) || this;
        _this.termConfig = assign({}, props.config, {
            cols: 80,
            cursorBlink: false,
            rows: 24,
            fontFamily: props.theme ? props.theme.monospace : theme.monospace,
            lineHeight: 1.4,
            theme: {
                background: '#343434',
                cursor: props.nonInteractive ? '#343434' : undefined,
            },
        });
        if (_this.props.ttyInstance) {
            _this.tty = _this.props.ttyInstance;
        }
        else {
            _this.tty = new Xterm(cloneDeep(_this.termConfig));
        }
        _this.resize = _this.resize.bind(_this);
        return _this;
    }
    Terminal.prototype.componentDidMount = function () {
        var _this = this;
        this.open();
        if (this.props.ttyInstance) {
            this.tty.setOption('theme', this.termConfig.theme);
        }
        setTimeout(function () {
            if (_this.props.nonInteractive && document.execCommand) {
                _this.tty.attachCustomKeyEventHandler(function (e) {
                    if (e.ctrlKey && e.keyCode === 67) {
                        document.execCommand('copy');
                        return false;
                    }
                    return true;
                });
            }
            window.addEventListener('resize', _this.resize);
            _this.resize();
        }, 100);
    };
    Terminal.prototype.componentWillUnmount = function () {
        window.removeEventListener('resize', this.resize);
        if (!this.props.persistent) {
            this.tty.destroy();
        }
    };
    Terminal.prototype.destroy = function () {
        window.removeEventListener('resize', this.resize);
        this.tty.destroy();
    };
    Terminal.prototype.open = function () {
        this.tty.open(this.mountElement);
        this.tty.focus();
    };
    Terminal.prototype.resize = function () {
        fitTerm(this.tty);
    };
    Terminal.prototype.clear = function () {
        this.tty.clear();
    };
    Terminal.prototype.writeln = function (line) {
        this.tty.writeln(line);
    };
    Terminal.prototype.write = function (text) {
        this.tty.write(text);
    };
    Terminal.prototype.render = function () {
        var _this = this;
        return (React.createElement(TtyContainer, { color: this.props.color },
            React.createElement(TtyInner, { ref: function (el) { return (_this.mountElement = el); } })));
    };
    return Terminal;
}(React.Component));
export default Terminal;
var templateObject_1, templateObject_2;
